==> seedsui-react-5.5.92.tgz: package/lib/locale/locale.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e2) { throw _e2; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e3) { didErr = true; err = _e3; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

import Interpolate from "./Interpolate";
/**
 * 国际化函数
 * @param {String} remark 用于没有key时将直接显示remark
 * @param {String} key 将从国际化文件中获取此key的值
 * @param {Array} variable 替换值中的变量{0}{1}, 数组中支持String|String<html>|Number|Node类型
 * @param {Boolean} dangerouslyHTML 变量是否需要将变量html字符串转换成reactDOM显示
 * @return {Node} 返回reactDOM
 */
// eslint-disable-next-line

export default function (remark, key, variable, dangerouslyHTML) {
  var locale = window.localeData; // 如果没有参数, 则返回国际化数据

  if (Array.from(arguments).length === 0) {
    return locale;
  } // 渲染国际化数据中对应的值


  if (key && locale) {
    var value = locale[key]; // 构建变量映射: 将[variable0, variable1]转换成{'0': variable0, '1': variable1}

    var variableMap = {};

    if (value && variable && Array.isArray(variable) && variable.length) {
      var _iterator = _createForOfIteratorHelper(variable.entries()),
          _step;

      try {
        for (_iterator.s(); !(_step = _iterator.n()).done;) {
          var _step$value = _slicedToArray(_step.value, 2),
              index = _step$value[0],
              variableItem = _step$value[1];

          variableMap["".concat(index)] = variableItem;
        }
      } catch (err) {
        _iterator.e(err);
      } finally {
        _iterator.f();
      }
    } // key的值value必须为string类型


    if (typeof value === 'string') {
      return Interpolate.variable(value, variableMap, dangerouslyHTML);
    }
  } // 没有国际化的值, 则渲染remark


  if (remark) return Interpolate.remark(remark, dangerouslyHTML);
  return '';
}

==> seedsui-react-5.7.93.tgz: package/lib/locale/locale.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e2) { throw _e2; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e3) { didErr = true; err = _e3; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
import Interpolate from "./Interpolate";

/**
 * 国际化函数
 * @param {String} remark 用于没有key时将直接显示remark
 * @param {String} key 将从国际化文件中获取此key的值
 * @param {Array} variable 替换值中的变量{0}{1}, 数组中支持String|String<html>|Number|Node类型
 * @param {Boolean} dangerouslyHTML 变量是否需要将变量html字符串转换成reactDOM显示
 * @return {Node} 返回reactDOM
 */
// eslint-disable-next-line
export default function (remark, key, variable, dangerouslyHTML) {
  var locale = window.localeData;
  // 如果没有参数, 则返回国际化数据
  if (Array.from(arguments).length === 0) {
    return locale;
  }
  // 渲染国际化数据中对应的值
  if (key && locale) {
    var value = locale[key];
    // 构建变量映射: 将[variable0, variable1]转换成{'0': variable0, '1': variable1}
    var variableMap = {};
    if (value && variable && Array.isArray(variable) && variable.length) {
      var _iterator = _createForOfIteratorHelper(variable.entries()),
        _step;
      try {
        for (_iterator.s(); !(_step = _iterator.n()).done;) {
          var _step$value = _slicedToArray(_step.value, 2),
            index = _step$value[0],
            variableItem = _step$value[1];
          variableMap["".concat(index)] = variableItem;
        }
      } catch (err) {
        _iterator.e(err);
      } finally {
        _iterator.f();
      }
    }

    // key的值value必须为string类型
    if (typeof value === 'string') {
      return Interpolate.variable(value, variableMap, dangerouslyHTML);
    }
  }
  // 没有国际化的值, 则渲染remark
  if (remark) return Interpolate.remark(remark, dangerouslyHTML);
  return '';
}
